@@ -15,6 +15,7 @@ import pandas as pd
 from sklearn.base import BaseEstimator, ClassifierMixin
 from sklearn.model_selection import cross_val_score
 from sklearn.utils.validation import check_array, check_is_fitted, check_X_y
+from imodels.util.arguments import check_fit_arguments
 
 from ..c45_tree.c45_utils import decision, is_numeric_feature, gain, gain_ratio, get_best_split, \
     set_as_leaf_node
@@ -138,7 +139,8 @@ class C45TreeClassifier(BaseEstimator, ClassifierMixin):
 
     def fit(self, X, y, feature_names: str = None):
         self.complexity_ = 0
-        X, y = check_X_y(X, y)
+        # X, y = check_X_y(X, y)
+        X, y, feature_names = check_fit_arguments(self, X, y, feature_names)
         self.resultType = type(y[0])
         if feature_names is None:
             self.feature_names = [f'X_{x}' for x in range(X.shape[1])]
@@ -146,9 +148,11 @@ class C45TreeClassifier(BaseEstimator, ClassifierMixin):
             # only include alphanumeric chars / replace spaces with underscores
             self.feature_names = [''.join([i for i in x if i.isalnum()]).replace(' ', '_')
                                   for x in feature_names]
-            self.feature_names = ['X_' + x if x[0].isdigit()
-                                  else x
-                                  for x in self.feature_names]
+            self.feature_names = [
+                'X_' + x if x[0].isdigit()
+                else x
+                for x in self.feature_names
+            ]
 
         assert len(self.feature_names) == X.shape[1]
 
